/* eslint-disable prettier/prettier */
import { defineComponent, ref } from "vue";

import PureTable from "@pureadmin/table";
import { pageContentProps } from "./types";
import { TableProBar } from "../../ReTable";
import { onBeforeRouteLeave } from "vue-router";
import { useColumns } from "./hooks/use-columns";
import { useActions } from "./hooks/use-actions";
import { useRequest } from "./hooks/use-request";
import { useSelection } from "./hooks/use-selection";
import { useRenderIcon } from "../../ReIcon/src/hooks";
import { createActionProps } from "./utils/create-operation";

import { useAppStoreHook } from "/@/store/modules/app";
import { useUserInfo } from "/@/hooks/core/useUser";
import { Operation } from "./actions";
import "./styles/index.scss";

import {
  ElButton,
  ElTooltip,
  ElCheckbox,
  ElScrollbar,
  ElButtonGroup,
  ElCheckboxGroup
} from "element-plus";

const PageContent = defineComponent({
  name: "PageContent",
  props: pageContentProps,
  emits: [
    "createBtnClick",
    "updateBtnClick",
    "statusBtnClick",
    "getContentData",
    "previewBtnClick",
    "selectionChange",
  ],
  setup(props, { expose, emit, slots }) {
    //根据传入的api决定表格需要的操作
    const tableRef = ref<InstanceType<typeof PureTable>>(null);

    const { setSearchParams } = useAppStoreHook();

    const {
      loading,
      dataList,
      onSearch,
      getPageData,
      onSearchPro,
      getPagination,
      getBasicParams,
      onBeforeAction,
      paginationConfig,
      initalData: intialData
    } = useRequest(props);

    const { isSuperUser } = useUserInfo();
    const { selects } = useSelection();
    const { action } = useActions(props.contentConfig);

    const { columns, fixed, displayColumns, _raw, reset } = useColumns(
      props.contentConfig.columns
    );

    function handleSelection(value) {
      selects.value = value;
      emit("selectionChange", value);
    }

    /**
     * 渲染需要的操作按钮
     */
    function renderOperation(row) {
      const { contentConfig, powers } = props;
      const {
        inv,
        apis,
        showStatus,
        notPreview,
        delTooltip,
        showDelete,
        showPreview,
        isRequestArray,
        superUserNoAction,
        superUserNoPerview: superUserNoPreview,
      } = contentConfig;

      const view = showPreview ? showPreview(row) : true;
      const del = showDelete ? showDelete(row) : true;

      console.log(del, powers, '~~🚀~~')

      const noAction =
        (superUserNoAction && !isSuperUser.value) || !superUserNoAction;
      const noPreview =
        (superUserNoPreview && !isSuperUser.value) || !superUserNoPreview;


      const _showStatus = showStatus
        ? showStatus(isSuperUser.value)
        : action.status &&
        noAction &&
        ((powers.some(i => i == "6") && row.status + "" === "0") ||
          (powers.some(i => i == "7") && row.status + "" === "1"));

      return (
        <>
          {!notPreview && view && noPreview && powers.some(i => i == "5") && (
            <Operation.Preview
              isInv={inv}
              onPreview={() => emit("previewBtnClick", row)}
            />
          )}

          {slots.custom && slots.custom(row)}
          {action.update && powers.some(i => i == "4") && noAction && (
            <Operation.Update
              onUpdate={() => emit("updateBtnClick", row)}
              {...createActionProps("update", apis)}
            />
          )}

          {_showStatus && (
            <Operation.Status
              row={row}
              prop={contentConfig.statusProp}
              statusRowProp={contentConfig.statusRowProp}
              onReload={() => onSearch()}
              isRequestArray={isRequestArray}
              {...createActionProps("status", apis)}
            />
          )}

          {del && noAction && action.delete && powers.some(i => i == "8") && (
            <Operation.Delete
              row={row}
              prop={contentConfig.deleteProp}
              delTooltip={delTooltip}
              onReload={() => onSearch()}
              {...createActionProps("delete", apis)}
            />
          )}
        </>
      );
    }

    function renderCreateButton() {
      const { contentConfig, powers } = props;
      const { superUserNoAction, showCreate } = contentConfig;

      if (
        (superUserNoAction && isSuperUser.value) ||
        (showCreate && !showCreate(isSuperUser.value))
      ) {
        return null;
      }

      return (
        (slots.create && slots.create()) ||
        (action.create && powers.some(i => i == "2") && (
          <Operation.Create
            {...createActionProps("create", contentConfig.apis)}
            onCreate={() => emit("createBtnClick")}
          />
        ))
      );
    }

    function renderButtons() {
      return (
        <div style={{ width: '100%', marginBottom: '5px' }}>
          {/* excel导出 */}
          <div v-if="props.contentConfig.title" class="float-left text-black font-bold" style="font-size:14px;padding-top:5px">
            <h2>{props.contentConfig.title}</h2>
            {slots.table_header && slots.table_header()}
          </div>
          <div class="float-right">
            {slots.header && slots.header()}
            {renderCreateButton()}
          </div>

          <div class="clear-both" />
        </div>
      );
    }

    onBeforeRouteLeave(({ path }) => {
      //到详情页保存查询参数 到其他页面清空查询参数
      // const isDetail = path.indexOf("Detail") >= 0;
      // const basicParams = isDetail && getBasicParams ? getBasicParams() : null;
      // const pagination = isDetail && getPagination ? getPagination() : null;
      // setSearchParams(basicParams, pagination);
    });

    const renderExpand = (row) => slots.expand && slots.expand(row)

    function renderFilterColumns() {
      return (
        <div class="filter-columns__content">
          <div class="filter-columns_reset">
            列筛选
            <ElButton type="text" onClick={() => reset()} size="small">
              重置
            </ElButton>
          </div>

          <ElScrollbar maxHeight={300} size="small">
            <ElCheckboxGroup v-model={displayColumns.value} size="small">
              {_raw.map(({ label, prop, fixed: fixedValue }, index) => {
                if (!label || label === "序号" || label === "z  ") return;
                return (
                  <div class="fixed-group">
                    <ElButtonGroup size="small">
                      <ElTooltip
                        content="固定在左边"
                        placement="top"
                        size="small"
                        disabled={fixedValue === "left"}
                      >
                        <ElButton
                          link
                          size="small"
                          icon={useRenderIcon("arrow-left-s-line")}
                          onClick={() => fixed("left", index)}
                        />
                      </ElTooltip>
                      <ElTooltip
                        content="固定在右边"
                        placement="top"
                        size="small"
                        disabled={fixedValue === "right"}
                      >
                        <ElButton
                          link
                          size="small"
                          icon={useRenderIcon("arrow-right-s-line")}
                          onClick={() => fixed("right", index)}
                        />
                      </ElTooltip>
                    </ElButtonGroup>
                    <ElCheckbox label={prop} key={prop} size="small">
                      {label}
                    </ElCheckbox>
                  </div>
                );
              })}
            </ElCheckboxGroup>
          </ElScrollbar>
        </div>
      );
    }

    function renderPureTable(size, checkList) {
      const { contentConfig } = props;
      const { treeProps, rowKey, isTree, maxHeight, spanMethod, tableRowClassName } = contentConfig;

      return (
        <PureTable
          ref={isTree && tableRef}
          border
          stripe
          defaultExp
          align="left"
          size="small"
          rowKey={rowKey}
          table-layout="auto"
          showOverflowTooltip
          columns={columns.value}
          treeProps={treeProps}
          data={dataList.value}
          checkList={checkList}
          spanMethod={spanMethod ? (data) => spanMethod(data, dataList.value) : undefined}
          maxHeight={maxHeight ? maxHeight : '660px'}
          rowClassName={tableRowClassName}
          paginationSmall={size === "small" ? true : false}
          headerCellStyle={{ background: "#fafafa", color: "#606266" }}
          onSelectionChange={handleSelection}
          {...paginationConfig}
          v-slots={{
            operation: ({ row }) => renderOperation(row),
            expand: ({ row }) => renderExpand(row)
          }}
        />
      );
    }

    expose({
      onSearch,
      onSearchPro,
      intialData,
      getPageData,
      getBasicParams,
      onBeforeAction,
      getData: () => dataList.value
    });

    return () => {
      const { contentConfig } = props;
      const { title, showTitle } = contentConfig;

      return (
        <TableProBar
          tableRef={tableRef.value?.getTableRef()}
          title={title}
          showTitle={showTitle}
          dataList={dataList.value}
          onRefresh={onSearch}
          loading={loading.value}
          custom
          v-slots={{
            buttons: () => renderButtons(),
            toolbar: () => renderFilterColumns(),
            default: ({ size, checkList }) => renderPureTable(size, checkList)
          }}
        />
      );
    };
  }
});

export default PageContent;
