/* eslint-disable prettier/prettier */
import { BeforeRequestType, ContentConfig } from "/@/components/PageContent";
import { subtraction } from "/@/utils/calc";
import { isBeyondTime } from "/@/views/reportCollection/_utils";
import apis from "./apis";


import dayjs from "dayjs"

import { addition } from "/@/utils/calc";

const columns = [
  {
    type: 'index',
    width: '60',
    label: '序号'
  },
  {
    label: '月份',
    prop: 'month',
    width: '80px'
  },
  {
    prop: 'companyName',
    label: '业务公司',
    minWidth: '155px'
  },
  {
    prop: 'supplierName',
    label: '供应商名称',
    minWidth: '155px'
  },

  {
    prop: 'hp_total',
    label: '买入回票金额合计',
    minWidth: '155px'
  },
  {
    prop: 'pay_total',
    label: '买入付款金额合计',
    minWidth: '155px'
  },
  {
    prop: 'rehp_total',
    label: '解除回票金额合计',
    minWidth: '155px'
  },
  {
    prop: 'repay_total',
    label: '解除付款金额合计',
    minWidth: '155px'
  },
  {

    prop: 'winv_total',
    label: '待开票金额',
    minWidth: '155px'
  },
  {
    prop: 'wpay_total',
    label: '待付款金额',
    minWidth: '155px'
  },
  {
    label: '回票金额合计',
    minWidth: '155px',
    cellRenderer({ row }) {
      return subtraction(row.hp_total, row.rehp_total)
    }
  },
  {
    label: '付款金额合计',
    minWidth: '155px',
    cellRenderer({ row }) {
      return subtraction(row.pay_total, row.repay_total)
    }
  }
]


const contentConfig: ContentConfig = {
  columns,
  showTitle: false,
  responseCode: 0,
  superUserNoAction: false,
  apis: { httpList: apis.list },
  handleData(data = []) {
    return new Promise(resolve => {

      const item = data.reduce((prev, current) => {
        return {
          hp_total: Number(addition(prev.hp_total, current.hp_total)).toFixed(2),
          pay_total: Number(addition(prev.pay_total, current.pay_total)).toFixed(2),
          rehp_total: Number(addition(prev.pay_total, current.pay_total)).toFixed(2),
          repay_total: Number(addition(prev.repay_total, current.repay_total)).toFixed(2),
          winv_total: Number(addition(prev.winv_total, current.winv_total)).toFixed(2),
          wpay_total: Number(addition(prev.wpay_total, current.wpay_total)).toFixed(2),
        }
      }, {
        hp_total: 0,
        pay_total: 0,
        rehp_total: 0,
        repay_total: 0,
        winv_total: 0,
        wpay_total: 0
      })

      resolve([{ ...item, month: data[0]?.month || '--', companyName: '合计', supplierName: '合计' }, ...data])
    })
  },
};


export default contentConfig;
